==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/nl-NL/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'Een account met dit e-mailadres bestaat reeds.',
    'account_not_found'      => 'De gebruikersnaam of het wachtwoord is niet juist.',
    'account_not_activated'  => 'Deze gebruikersaccount is niet actief.',
    'account_suspended'      => 'Deze gebruikersaccount is vergrendeld.',
    'account_banned'         => 'Deze gebruikersaccount is geband.',
    'throttle'               => 'Te veel mislukte inlog pogingen. Probeer het over :minuten opnieuw.',

    'two_factor' => array(
        'already_enrolled'      => 'Je apparaat is al uitgeleverd.',
        'success'               => 'U bent succesvol ingelogd.',
        'code_required'         => 'Tweestapsverificatie code is vereist.',
        'invalid_code'          => 'Tweestapsverificatie code is ongeldig.',
        'enter_two_factor_code' => 'Please enter your two-factor authentication code.',
        'please_enroll'         => 'Please enroll a device in two-factor authentication.',
    ),

    'signin' => array(
        'error'   => 'Er was een probleem bij inloggen, probeer opnieuw aub.',
        'success' => 'U bent succesvol aangemeld.',
    ),

    'logout' => array(
        'error'   => 'Er is een probleem opgetreden bij het uitloggen, probeer het nogmaals.',
        'success' => 'U bent succesvol uitgelogd.',
    ),

    'signup' => array(
        'error'   => 'Er was een probleem bij het aanmaken van uw account, probeer opnieuw aub.',
        'success' => 'Gebruikersaccount succesvol aangemaakt.',
    ),

    'forgot-password' => array(
        'error'   => 'Er was een probleem bij het ophalen van de paswoord herstelcode, probeer opnieuw aub.',
        'success' => 'Als dat e-mailadres in ons systeem bestaat, is er een e-mail gestuurd om het wachtwoord te herstellen.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Er was een probleem bij het opnieuw instellen van uw wachtwoord, probeer opnieuw aub.',
        'success' => 'Uw wachtwoord werd hersteld.',
    ),


);

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/nl-NL/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'Een account met dit e-mailadres bestaat reeds.',
    'account_not_found'      => 'De gebruikersnaam of het wachtwoord is niet juist.',
    'account_not_activated'  => 'Deze gebruikersaccount is niet actief.',
    'account_suspended'      => 'Deze gebruikersaccount is vergrendeld.',
    'account_banned'         => 'Deze gebruikersaccount is geband.',
    'throttle'               => 'Te veel mislukte inlog pogingen. Probeer het over :minuten opnieuw.',

    'two_factor' => array(
        'already_enrolled'      => 'Je apparaat is al uitgeleverd.',
        'success'               => 'U bent succesvol ingelogd.',
        'code_required'         => 'Tweestapsverificatie code is vereist.',
        'invalid_code'          => 'Tweestapsverificatie code is ongeldig.',
        'enter_two_factor_code' => 'Voer je tweestaps verificatiecode in.',
        'please_enroll'         => 'Registreer een apparaat voor twee-factor-authenticatie.',
    ),

    'signin' => array(
        'error'   => 'Er was een probleem bij inloggen, probeer opnieuw aub.',
        'success' => 'U bent succesvol aangemeld.',
    ),

    'logout' => array(
        'error'   => 'Er is een probleem opgetreden bij het uitloggen, probeer het nogmaals.',
        'success' => 'U bent succesvol uitgelogd.',
    ),

    'signup' => array(
        'error'   => 'Er was een probleem bij het aanmaken van uw account, probeer opnieuw aub.',
        'success' => 'Gebruikersaccount succesvol aangemaakt.',
    ),

    'forgot-password' => array(
        'error'   => 'Er was een probleem bij het ophalen van de paswoord herstelcode, probeer opnieuw aub.',
        'success' => 'Als dat e-mailadres in ons systeem bestaat, is er een e-mail gestuurd om het wachtwoord te herstellen.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Er was een probleem bij het opnieuw instellen van uw wachtwoord, probeer opnieuw aub.',
        'success' => 'Uw wachtwoord werd hersteld.',
    ),


);
